@@ -1218,16 +1218,20 @@ class Rule(object):
             proto = "!"
         else:
             proto = ""
-        proto = "".join([proto, self.protocols[self.entry.ip.proto]])
+        proto = "".join([proto, self.protocols.get(self.entry.ip.proto, str(self.entry.ip.proto))])
         return proto
 
     def set_protocol(self, proto):
+        proto = str(proto)
         if proto[0] == "!":
             self.entry.ip.invflags |= ipt_ip.IPT_INV_PROTO
             proto = proto[1:]
         else:
             self.entry.ip.invflags &= (~ipt_ip.IPT_INV_PROTO &
                                        ipt_ip.IPT_INV_MASK)
+        if proto.isdigit():
+            self.entry.ip.proto = int(proto)
+            return
         for p in self.protocols.items():
             if proto.lower() == p[1]:
                 self.entry.ip.proto = p[0]
@@ -1465,7 +1469,12 @@ class Chain(object):
         return [self.table.create_rule(e, self) for e in entries]
 
     rules = property(_get_rules)
-    """This is the list of rules currently in the chain."""
+    """This is the list of rules currently in the chain.
+
+    The indexes of the Rule items produced from this list *should* correspond
+    to the IPTables --line-numbers value minus one.  Keeping in mind that
+    iptables rules are 1-indexed whereas the Python list is 0-indexed
+    """
 
 
 def autocommit(fn):
